representation of DOT graph of the dependency tree of typical highest-level single pointing analysis:

![schema](http://www.apc.univ-paris7.fr/Downloads/astrog/savchenk/imgb/schema.png.1399478739.e5d43e4b9b)
